# coding: utf-8

"""
    Allegro REST API

    https://developer.allegro.pl/about  # noqa: E501

    The version of the OpenAPI document: 2020.03.10
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import allegro_api
from allegro_api.models.additional_services_groups import AdditionalServicesGroups  # noqa: E501
from allegro_api.rest import ApiException

class TestAdditionalServicesGroups(unittest.TestCase):
    """AdditionalServicesGroups unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test AdditionalServicesGroups
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = allegro_api.models.additional_services_groups.AdditionalServicesGroups()  # noqa: E501
        if include_optional :
            return AdditionalServicesGroups(
                additional_services_groups = [
                    allegro_api.models.additional_services_group_response.AdditionalServicesGroupResponse(
                        additional_services = [
                            allegro_api.models.additional_service_response.AdditionalServiceResponse(
                                configurations = [
                                    allegro_api.models.configuration.Configuration(
                                        constraints = allegro_api.models.constraint_criteria.ConstraintCriteria(
                                            country = '0', 
                                            type = 'COUNTRY_SAME_QUANTITY', 
                                            delivery_methods = [
                                                allegro_api.models.just_id.JustId(
                                                    id = '0', )
                                                ], ), 
                                        price = allegro_api.models.price.Price(
                                            amount = '123.45', 
                                            currency = 'PLN', ), )
                                    ], 
                                definition = allegro_api.models.basic_definition_response.BasicDefinitionResponse(
                                    id = '0', ), 
                                description = '0', )
                            ], 
                        created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        id = '0', 
                        updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        name = '0', 
                        seller = allegro_api.models.reference.Reference(
                            id = '0', ), )
                    ]
            )
        else :
            return AdditionalServicesGroups(
        )

    def testAdditionalServicesGroups(self):
        """Test AdditionalServicesGroups"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Allegro REST API

    https://developer.allegro.pl/about  # noqa: E501

    The version of the OpenAPI document: 2020.03.10
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import allegro_api
from allegro_api.models.checkout_form import CheckoutForm  # noqa: E501
from allegro_api.rest import ApiException

class TestCheckoutForm(unittest.TestCase):
    """CheckoutForm unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test CheckoutForm
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = allegro_api.models.checkout_form.CheckoutForm()  # noqa: E501
        if include_optional :
            return CheckoutForm(
                id = '29738e61-7f6a-11e8-ac45-09db60ede9d6', 
                message_to_seller = 'Please send me an item in red color', 
                buyer = allegro_api.models.checkout_form_buyer_reference.CheckoutFormBuyerReference(
                    id = '23123123', 
                    email = 'user-email@allegro.pl', 
                    login = 'User_Login', 
                    first_name = 'Jan', 
                    last_name = 'Kowalski', 
                    company_name = '0', 
                    guest = False, 
                    personal_identity = '67062589524', 
                    phone_number = '0', 
                    address = allegro_api.models.checkout_form_buyer_address_reference.CheckoutFormBuyerAddressReference(
                        street = 'Solna', 
                        city = 'Poznań', 
                        post_code = '60-166', 
                        country_code = 'PL', ), ), 
                payment = allegro_api.models.checkout_form_payment_reference.CheckoutFormPaymentReference(
                    id = '0f8f1d13-7e9e-11e8-9b00-c5b0dfb78ea6', 
                    type = 'CASH_ON_DELIVERY', 
                    provider = 'P24', 
                    finished_at = '2018-10-12T10:12:32.321Z', 
                    paid_amount = allegro_api.models.price.Price(
                        amount = '123.45', 
                        currency = 'PLN', ), ), 
                status = 'READY_FOR_PROCESSING', 
                fulfillment = allegro_api.models.checkout_form_fulfillment.CheckoutFormFulfillment(
                    status = 'SENT', 
                    shipment_summary = allegro_api.models.checkout_form_fulfillment_shipment_summary.CheckoutFormFulfillmentShipmentSummary(
                        line_items_sent = 'SOME', ), ), 
                delivery = allegro_api.models.checkout_form_delivery_reference.CheckoutFormDeliveryReference(
                    address = allegro_api.models.checkout_form_delivery_address.CheckoutFormDeliveryAddress(
                        first_name = 'Jan', 
                        last_name = 'Kowalski', 
                        street = 'Grunwaldzka 182', 
                        city = 'Poznań', 
                        zip_code = '60-166', 
                        country_code = 'PL', 
                        company_name = '0', 
                        phone_number = '0', ), 
                    method = allegro_api.models.checkout_form_delivery_method.CheckoutFormDeliveryMethod(
                        id = '1fa56f79-4b6a-4821-a6f2-ca9c16d5c925', 
                        name = 'Allegro Paczkomaty InPost', ), 
                    pickup_point = allegro_api.models.checkout_form_delivery_pickup_point.CheckoutFormDeliveryPickupPoint(
                        id = 'POZ08A', 
                        name = 'Paczkomat POZ08A', 
                        description = 'Stacja paliw BP', ), 
                    cost = allegro_api.models.price.Price(
                        amount = '123.45', 
                        currency = 'PLN', ), 
                    time = allegro_api.models.checkout_form_delivery_time.CheckoutFormDeliveryTime(
                        guaranteed = allegro_api.models.checkout_form_delivery_time_guaranteed.CheckoutFormDeliveryTimeGuaranteed(
                            from = '2018-01-01T16:00Z', 
                            to = '2018-01-01T18:00Z', ), ), 
                    smart = True, 
                    calculated_number_of_packages = 1, ), 
                invoice = allegro_api.models.checkout_form_invoice_info.CheckoutFormInvoiceInfo(
                    required = True, 
                    address = allegro_api.models.checkout_form_invoice_address.CheckoutFormInvoiceAddress(
                        street = 'Grunwaldzka 182', 
                        city = 'Poznań', 
                        zip_code = '60-166', 
                        country_code = 'PL', 
                        company = allegro_api.models.checkout_form_invoice_address_company.CheckoutFormInvoiceAddressCompany(
                            name = 'Udix Sp. z o.o.', 
                            tax_id = '0', ), 
                        natural_person = allegro_api.models.checkout_form_invoice_address_natural_person.CheckoutFormInvoiceAddressNaturalPerson(
                            first_name = 'Jan', 
                            last_name = 'Kowalski', ), ), ), 
                line_items = [
                    allegro_api.models.checkout_form_line_item.CheckoutFormLineItem(
                        id = '62ae358b-8f65-4fc4-9c77-bedf604a2e2b', 
                        offer = allegro_api.models.offer_reference.OfferReference(
                            id = '3213213', 
                            name = 'Name of purchased offer', 
                            external = allegro_api.models.external_id.ExternalId(
                                id = 'AH-129834', ), ), 
                        quantity = 1, 
                        original_price = allegro_api.models.price.Price(
                            amount = '123.45', 
                            currency = 'PLN', ), 
                        price = allegro_api.models.price.Price(
                            amount = '123.45', 
                            currency = 'PLN', ), 
                        selected_additional_services = [
                            allegro_api.models.checkout_form_additional_service.CheckoutFormAdditionalService(
                                definition_id = 'CARRY_IN', 
                                name = 'Wniesienie', 
                                quantity = 1, )
                            ], 
                        bought_at = '2018-01-01T10:23:43.123Z', )
                    ], 
                surcharges = [
                    allegro_api.models.checkout_form_payment_reference.CheckoutFormPaymentReference(
                        id = '0f8f1d13-7e9e-11e8-9b00-c5b0dfb78ea6', 
                        type = 'CASH_ON_DELIVERY', 
                        provider = 'P24', 
                        finished_at = '2018-10-12T10:12:32.321Z', 
                        paid_amount = allegro_api.models.price.Price(
                            amount = '123.45', 
                            currency = 'PLN', ), )
                    ], 
                discounts = [
                    allegro_api.models.checkout_form_discount.CheckoutFormDiscount(
                        type = 'COUPON', )
                    ], 
                summary = allegro_api.models.checkout_form_summary.CheckoutFormSummary(
                    total_to_pay = null, ), 
                updated_at = '2011-12-03T10:15:30.133Z'
            )
        else :
            return CheckoutForm(
                id = '29738e61-7f6a-11e8-ac45-09db60ede9d6',
                buyer = allegro_api.models.checkout_form_buyer_reference.CheckoutFormBuyerReference(
                    id = '23123123', 
                    email = 'user-email@allegro.pl', 
                    login = 'User_Login', 
                    first_name = 'Jan', 
                    last_name = 'Kowalski', 
                    company_name = '0', 
                    guest = False, 
                    personal_identity = '67062589524', 
                    phone_number = '0', 
                    address = allegro_api.models.checkout_form_buyer_address_reference.CheckoutFormBuyerAddressReference(
                        street = 'Solna', 
                        city = 'Poznań', 
                        post_code = '60-166', 
                        country_code = 'PL', ), ),
                status = 'READY_FOR_PROCESSING',
                line_items = [
                    allegro_api.models.checkout_form_line_item.CheckoutFormLineItem(
                        id = '62ae358b-8f65-4fc4-9c77-bedf604a2e2b', 
                        offer = allegro_api.models.offer_reference.OfferReference(
                            id = '3213213', 
                            name = 'Name of purchased offer', 
                            external = allegro_api.models.external_id.ExternalId(
                                id = 'AH-129834', ), ), 
                        quantity = 1, 
                        original_price = allegro_api.models.price.Price(
                            amount = '123.45', 
                            currency = 'PLN', ), 
                        price = allegro_api.models.price.Price(
                            amount = '123.45', 
                            currency = 'PLN', ), 
                        selected_additional_services = [
                            allegro_api.models.checkout_form_additional_service.CheckoutFormAdditionalService(
                                definition_id = 'CARRY_IN', 
                                name = 'Wniesienie', 
                                quantity = 1, )
                            ], 
                        bought_at = '2018-01-01T10:23:43.123Z', )
                    ],
                surcharges = [
                    allegro_api.models.checkout_form_payment_reference.CheckoutFormPaymentReference(
                        id = '0f8f1d13-7e9e-11e8-9b00-c5b0dfb78ea6', 
                        type = 'CASH_ON_DELIVERY', 
                        provider = 'P24', 
                        finished_at = '2018-10-12T10:12:32.321Z', 
                        paid_amount = allegro_api.models.price.Price(
                            amount = '123.45', 
                            currency = 'PLN', ), )
                    ],
                discounts = [
                    allegro_api.models.checkout_form_discount.CheckoutFormDiscount(
                        type = 'COUPON', )
                    ],
                summary = allegro_api.models.checkout_form_summary.CheckoutFormSummary(
                    total_to_pay = null, ),
        )

    def testCheckoutForm(self):
        """Test CheckoutForm"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Allegro REST API

    https://developer.allegro.pl/about  # noqa: E501

    The version of the OpenAPI document: 2020.03.10
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import allegro_api
from allegro_api.models.user_rating import UserRating  # noqa: E501
from allegro_api.rest import ApiException

class TestUserRating(unittest.TestCase):
    """UserRating unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test UserRating
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = allegro_api.models.user_rating.UserRating()  # noqa: E501
        if include_optional :
            return UserRating(
                answer = allegro_api.models.answer.Answer(
                    created_at = '2017-05-17T08:36:57.292+02:00', 
                    message = '0', ), 
                buyer = allegro_api.models.user.User(
                    id = '0', 
                    login = '0', ), 
                comment = '0', 
                created_at = '2017-05-17T08:36:57.292+02:00', 
                excluded_from_average_rates = False, 
                id = '0', 
                order = allegro_api.models.order.Order(
                    id = '0', 
                    offers = [
                        allegro_api.models.offer.Offer(
                            additional_services = allegro_api.models.just_id.JustId(
                                id = '0', ), 
                            after_sales_services = allegro_api.models.after_sales_services.AfterSalesServices(
                                implied_warranty = allegro_api.models.implied_warranty.ImpliedWarranty(
                                    id = '09f0b4cc-7880-11e9-8f9e-2a86e4085a59', ), 
                                return_policy = allegro_api.models.return_policy.ReturnPolicy(
                                    id = '09f0b4cc-7880-11e9-8f9e-2a86e4085a59', ), 
                                warranty = allegro_api.models.warranty.Warranty(
                                    id = '09f0b4cc-7880-11e9-8f9e-2a86e4085a59', ), ), 
                            attachments = [
                                allegro_api.models.attachment.Attachment(
                                    id = '1928302_MANUAL_45d7a0f543e1b0d05e12a1aef5642efe63389a1d419fe9286d0f158044391fdce', )
                                ], 
                            category = allegro_api.models.category.Category(
                                id = '0', ), 
                            compatibility_list = allegro_api.models.compatibility_list.CompatibilityList(), 
                            contact = allegro_api.models.just_id.JustId(
                                id = '0', ), 
                            created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                            delivery = allegro_api.models.delivery.Delivery(
                                additional_info = '0', 
                                handling_time = 'PDT12H30M5S', 
                                shipment_date = '2018-04-01T08:00Z', 
                                shipping_rates = allegro_api.models.just_id.JustId(
                                    id = '0', ), ), 
                            description = allegro_api.models.standardized_description.StandardizedDescription(
                                sections = [
                                    allegro_api.models.description_section.DescriptionSection(
                                        items = [
                                            allegro_api.models.description_section_item.DescriptionSectionItem(
                                                type = '0', )
                                            ], )
                                    ], ), 
                            ean = '0', 
                            external = allegro_api.models.external_id.ExternalId(
                                id = 'AH-129834', ), 
                            id = '0', 
                            images = [
                                allegro_api.models.image_url.ImageUrl(
                                    url = '0', )
                                ], 
                            location = allegro_api.models.location.Location(
                                city = '0', 
                                country_code = '0', 
                                post_code = '0', 
                                province = '0', ), 
                            name = '0', 
                            parameters = [
                                allegro_api.models.parameter.Parameter(
                                    id = '0', 
                                    range_value = allegro_api.models.parameter_range_value.ParameterRangeValue(
                                        from = '0', 
                                        to = '0', ), 
                                    values = [
                                        '0'
                                        ], 
                                    values_ids = [
                                        '0'
                                        ], )
                                ], 
                            payments = allegro_api.models.payments.Payments(
                                invoice = '0', ), 
                            product = allegro_api.models.just_id.JustId(
                                id = '0', ), 
                            promotion = allegro_api.models.promotion.Promotion(
                                bold = True, 
                                department_page = True, 
                                emphasized = True, 
                                emphasized_highlight_bold_package = True, 
                                highlight = True, ), 
                            publication = allegro_api.models.publication.Publication(
                                duration = 'PDT12H30M5S', 
                                ending_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                starting_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                status = 'INACTIVE', 
                                ended_by = 'USER', 
                                republish = False, ), 
                            selling_mode = allegro_api.models.selling_mode.SellingMode(
                                format = 'BUY_NOW', 
                                price = null, 
                                minimal_price = null, 
                                starting_price = null, ), 
                            size_table = allegro_api.models.just_id.JustId(
                                id = '0', ), 
                            stock = allegro_api.models.stock.Stock(
                                available = 56, 
                                unit = '0', ), 
                            tecdoc_specification = allegro_api.models.tecdoc_specification.TecdocSpecification(
                                id = '470b8513-b786-b7b9-9e7e-2f848729cfd6', ), 
                            updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                            validation = allegro_api.models.validation.Validation(
                                errors = [
                                    allegro_api.models.validation_error.ValidationError(
                                        code = '0', 
                                        details = '0', 
                                        message = '0', 
                                        path = '0', 
                                        user_message = '0', )
                                    ], 
                                validated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), ), )
                        ], ), 
                rates = allegro_api.models.rates.Rates(
                    delivery = 5, 
                    delivery_cost = 5, 
                    description = 5, 
                    service = 5, ), 
                recommended = False, 
                removal = allegro_api.models.removal.Removal(
                    possible_to = '2017-05-17T08:36:57.292+02:00', 
                    request = allegro_api.models.removal_request.RemovalRequest(
                        created_at = '2017-05-17T08:36:57.292+02:00', 
                        message = '0', ), )
            )
        else :
            return UserRating(
                buyer = allegro_api.models.user.User(
                    id = '0', 
                    login = '0', ),
                comment = '0',
                created_at = '2017-05-17T08:36:57.292+02:00',
                id = '0',
                recommended = False,
        )

    def testUserRating(self):
        """Test UserRating"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Allegro REST API

    https://developer.allegro.pl/about  # noqa: E501

    The version of the OpenAPI document: 2020.03.10
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from allegro_api.configuration import Configuration


class ClassifiedPackageConfig(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'extensions': 'list[ClassifiedExtension]',
        'id': 'str',
        'name': 'str',
        'promotions': 'list[ClassifiedPromotion]',
        'publication': 'ClassifiedPublication',
        'type': 'str'
    }

    attribute_map = {
        'extensions': 'extensions',
        'id': 'id',
        'name': 'name',
        'promotions': 'promotions',
        'publication': 'publication',
        'type': 'type'
    }

    def __init__(self, extensions=None, id=None, name=None, promotions=None, publication=None, type=None, local_vars_configuration=None):  # noqa: E501
        """ClassifiedPackageConfig - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._extensions = None
        self._id = None
        self._name = None
        self._promotions = None
        self._publication = None
        self._type = None
        self.discriminator = None

        if extensions is not None:
            self.extensions = extensions
        self.id = id
        self.name = name
        if promotions is not None:
            self.promotions = promotions
        if publication is not None:
            self.publication = publication
        self.type = type

    @property
    def extensions(self):
        """Gets the extensions of this ClassifiedPackageConfig.  # noqa: E501


        :return: The extensions of this ClassifiedPackageConfig.  # noqa: E501
        :rtype: list[ClassifiedExtension]
        """
        return self._extensions

    @extensions.setter
    def extensions(self, extensions):
        """Sets the extensions of this ClassifiedPackageConfig.


        :param extensions: The extensions of this ClassifiedPackageConfig.  # noqa: E501
        :type: list[ClassifiedExtension]
        """

        self._extensions = extensions

    @property
    def id(self):
        """Gets the id of this ClassifiedPackageConfig.  # noqa: E501

        The classifieds package ID.  # noqa: E501

        :return: The id of this ClassifiedPackageConfig.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this ClassifiedPackageConfig.

        The classifieds package ID.  # noqa: E501

        :param id: The id of this ClassifiedPackageConfig.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and id is None:  # noqa: E501
            raise ValueError("Invalid value for `id`, must not be `None`")  # noqa: E501

        self._id = id

    @property
    def name(self):
        """Gets the name of this ClassifiedPackageConfig.  # noqa: E501

        The classifieds package name.  # noqa: E501

        :return: The name of this ClassifiedPackageConfig.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this ClassifiedPackageConfig.

        The classifieds package name.  # noqa: E501

        :param name: The name of this ClassifiedPackageConfig.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and name is None:  # noqa: E501
            raise ValueError("Invalid value for `name`, must not be `None`")  # noqa: E501

        self._name = name

    @property
    def promotions(self):
        """Gets the promotions of this ClassifiedPackageConfig.  # noqa: E501

        A list of additional promotions included in the package.  # noqa: E501

        :return: The promotions of this ClassifiedPackageConfig.  # noqa: E501
        :rtype: list[ClassifiedPromotion]
        """
        return self._promotions

    @promotions.setter
    def promotions(self, promotions):
        """Sets the promotions of this ClassifiedPackageConfig.

        A list of additional promotions included in the package.  # noqa: E501

        :param promotions: The promotions of this ClassifiedPackageConfig.  # noqa: E501
        :type: list[ClassifiedPromotion]
        """

        self._promotions = promotions

    @property
    def publication(self):
        """Gets the publication of this ClassifiedPackageConfig.  # noqa: E501


        :return: The publication of this ClassifiedPackageConfig.  # noqa: E501
        :rtype: ClassifiedPublication
        """
        return self._publication

    @publication.setter
    def publication(self, publication):
        """Sets the publication of this ClassifiedPackageConfig.


        :param publication: The publication of this ClassifiedPackageConfig.  # noqa: E501
        :type: ClassifiedPublication
        """

        self._publication = publication

    @property
    def type(self):
        """Gets the type of this ClassifiedPackageConfig.  # noqa: E501


        :return: The type of this ClassifiedPackageConfig.  # noqa: E501
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        """Sets the type of this ClassifiedPackageConfig.


        :param type: The type of this ClassifiedPackageConfig.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and type is None:  # noqa: E501
            raise ValueError("Invalid value for `type`, must not be `None`")  # noqa: E501
        allowed_values = ["BASE", "EXTRA"]  # noqa: E501
        if self.local_vars_configuration.client_side_validation and type not in allowed_values:  # noqa: E501
            raise ValueError(
                "Invalid value for `type` ({0}), must be one of {1}"  # noqa: E501
                .format(type, allowed_values)
            )

        self._type = type

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ClassifiedPackageConfig):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, ClassifiedPackageConfig):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Allegro REST API

    https://developer.allegro.pl/about  # noqa: E501

    The version of the OpenAPI document: 2020.03.10
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest

import allegro_api
from allegro_api.api.sets_and_rebates_api import SetsAndRebatesApi  # noqa: E501
from allegro_api.rest import ApiException


class TestSetsAndRebatesApi(unittest.TestCase):
    """SetsAndRebatesApi unit test stubs"""

    def setUp(self):
        self.api = allegro_api.api.sets_and_rebates_api.SetsAndRebatesApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_create_promotion_using_post1(self):
        """Test case for create_promotion_using_post1

        Create a new promotion  # noqa: E501
        """
        pass

    def test_deactivate_promotion_using_delete(self):
        """Test case for deactivate_promotion_using_delete

        Deactivate a promotion by id  # noqa: E501
        """
        pass

    def test_get_promotion_using_get(self):
        """Test case for get_promotion_using_get

        Get a promotion data by id  # noqa: E501
        """
        pass

    def test_list_seller_promotions_using_get1(self):
        """Test case for list_seller_promotions_using_get1

        Get the user's list of promotions  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Allegro REST API

    https://developer.allegro.pl/about  # noqa: E501

    The version of the OpenAPI document: 2020.03.10
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from allegro_api.api_client import ApiClient
from allegro_api.exceptions import (
    ApiTypeError,
    ApiValueError
)


class ImagesAndAttachmentsApi(object):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def create_offer_attachment_using_post(self, offer_attachment_request, **kwargs):  # noqa: E501
        """Create an offer attachment  # noqa: E501

        You can attach PDF files to your offers. We will present them under the offer description in the Additional information section. You can attach up to 7 files to one offer – one per each type from the list:   * \\- Guide (MANUAL)   * \\- Special offer terms (SPECIAL_OFFER_RULES)   * \\- Competition terms (COMPETITION_RULES)   * \\- Book excerpt (BOOK_EXCERPT)   * \\- Manual (USER_MANUAL)   * \\- Installation manual (INSTALLATION_INSTRUCTIONS)   * \\- Game manual (GAME_INSTRUCTIONS)  Uploading attachments flow:   1. Create an attachment object to receive an upload URL (*POST /sale/offer-attachments*),   2. Use the upload URL to submit the PDF file (*PUT /sale/offer-attachments/{attachmentId}*),   3. Add attachments to the offer (*PUT /sale/offers/{offerId}*).  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.create_offer_attachment_using_post(offer_attachment_request, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param OfferAttachmentRequest offer_attachment_request: offer attachment (required)
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: OfferAttachment
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.create_offer_attachment_using_post_with_http_info(offer_attachment_request, **kwargs)  # noqa: E501

    def create_offer_attachment_using_post_with_http_info(self, offer_attachment_request, **kwargs):  # noqa: E501
        """Create an offer attachment  # noqa: E501

        You can attach PDF files to your offers. We will present them under the offer description in the Additional information section. You can attach up to 7 files to one offer – one per each type from the list:   * \\- Guide (MANUAL)   * \\- Special offer terms (SPECIAL_OFFER_RULES)   * \\- Competition terms (COMPETITION_RULES)   * \\- Book excerpt (BOOK_EXCERPT)   * \\- Manual (USER_MANUAL)   * \\- Installation manual (INSTALLATION_INSTRUCTIONS)   * \\- Game manual (GAME_INSTRUCTIONS)  Uploading attachments flow:   1. Create an attachment object to receive an upload URL (*POST /sale/offer-attachments*),   2. Use the upload URL to submit the PDF file (*PUT /sale/offer-attachments/{attachmentId}*),   3. Add attachments to the offer (*PUT /sale/offers/{offerId}*).  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.create_offer_attachment_using_post_with_http_info(offer_attachment_request, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param OfferAttachmentRequest offer_attachment_request: offer attachment (required)
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(OfferAttachment, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = ['offer_attachment_request']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method create_offer_attachment_using_post" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'offer_attachment_request' is set
        if self.api_client.client_side_validation and ('offer_attachment_request' not in local_var_params or  # noqa: E501
                                                        local_var_params['offer_attachment_request'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `offer_attachment_request` when calling `create_offer_attachment_using_post`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'offer_attachment_request' in local_var_params:
            body_params = local_var_params['offer_attachment_request']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/vnd.allegro.public.v1+json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/vnd.allegro.public.v1+json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['bearer-token-for-user']  # noqa: E501

        return self.api_client.call_api(
            '/sale/offer-attachments', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='OfferAttachment',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def upload_offer_attachment_using_put(self, attachment_id, **kwargs):  # noqa: E501
        """Upload an offer attachment  # noqa: E501

        Upload an offer attachment. This operation should be used after creating an offer attachment with *POST /sale/offer-attachments* **Important!** You can find the URL address to upload the file to our server in the *Location* response header of *POST /sale/offer-attachments*. The URL is unique and one-time. As its format may change in time, you should always use the address from the header. Do not compose the address on your own.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.upload_offer_attachment_using_put(attachment_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str attachment_id: The ID of the attachment. (required)
        :param file body:
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.upload_offer_attachment_using_put_with_http_info(attachment_id, **kwargs)  # noqa: E501

    def upload_offer_attachment_using_put_with_http_info(self, attachment_id, **kwargs):  # noqa: E501
        """Upload an offer attachment  # noqa: E501

        Upload an offer attachment. This operation should be used after creating an offer attachment with *POST /sale/offer-attachments* **Important!** You can find the URL address to upload the file to our server in the *Location* response header of *POST /sale/offer-attachments*. The URL is unique and one-time. As its format may change in time, you should always use the address from the header. Do not compose the address on your own.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.upload_offer_attachment_using_put_with_http_info(attachment_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str attachment_id: The ID of the attachment. (required)
        :param file body:
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_hosts = ['https://upload.{environment}']  # noqa: E501
        local_var_host = local_var_hosts[0]
        if kwargs.get('_host_index'):
            if int(kwags.get('_host_index')) < 0 or int(kawgs.get('_host_index')) >= len(local_var_hosts):
                raise ApiValueError("Invalid host index. Must be 0 <= index < %s" % len(local_var_host))
            local_var_host = local_var_hosts[int(kwargs.get('_host_index'))]
        local_var_params = locals()

        all_params = ['attachment_id', 'body']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params and key != "_host_index":
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method upload_offer_attachment_using_put" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'attachment_id' is set
        if self.api_client.client_side_validation and ('attachment_id' not in local_var_params or  # noqa: E501
                                                        local_var_params['attachment_id'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `attachment_id` when calling `upload_offer_attachment_using_put`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'attachment_id' in local_var_params:
            path_params['attachmentId'] = local_var_params['attachment_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in local_var_params:
            body_params = local_var_params['body']
        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/pdf'])  # noqa: E501

        # Authentication setting
        auth_settings = ['bearer-token-for-user']  # noqa: E501

        return self.api_client.call_api(
            '/sale/offer-attachments/{attachmentId}', 'PUT',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            _host=local_var_host,
            collection_formats=collection_formats)

    def upload_offer_image_using_post(self, offer_image_link_upload_request, **kwargs):  # noqa: E501
        """Upload an offer image  # noqa: E501

        Upload image to our servers. You can choose from two upload options:   * \\- provide a link and we will download an image for you   * \\- send an image as binary data  **Important!** Remember to use dedicated domain for upload, i.e.   * \\- https://upload.allegro.pl for Production   * \\- https://upload.allegro.pl.allegrosandbox.pl for Sandbox  More information about rules for photos in an offer's gallery and description you will find <a href=\"https://allegro.pl/dla-sprzedajacych/nowe-zasady-dla-zdjec-w-galerii-i-w-opisie-YLlAAa2oXf7\" target=\"_blank\">here</a>.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.upload_offer_image_using_post(offer_image_link_upload_request, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param OfferImageLinkUploadRequest offer_image_link_upload_request: (required)
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: OfferImageUploadResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.upload_offer_image_using_post_with_http_info(offer_image_link_upload_request, **kwargs)  # noqa: E501

    def upload_offer_image_using_post_with_http_info(self, offer_image_link_upload_request, **kwargs):  # noqa: E501
        """Upload an offer image  # noqa: E501

        Upload image to our servers. You can choose from two upload options:   * \\- provide a link and we will download an image for you   * \\- send an image as binary data  **Important!** Remember to use dedicated domain for upload, i.e.   * \\- https://upload.allegro.pl for Production   * \\- https://upload.allegro.pl.allegrosandbox.pl for Sandbox  More information about rules for photos in an offer's gallery and description you will find <a href=\"https://allegro.pl/dla-sprzedajacych/nowe-zasady-dla-zdjec-w-galerii-i-w-opisie-YLlAAa2oXf7\" target=\"_blank\">here</a>.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.upload_offer_image_using_post_with_http_info(offer_image_link_upload_request, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param OfferImageLinkUploadRequest offer_image_link_upload_request: (required)
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(OfferImageUploadResponse, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_hosts = ['https://upload.{environment}']  # noqa: E501
        local_var_host = local_var_hosts[0]
        if kwargs.get('_host_index'):
            if int(kwags.get('_host_index')) < 0 or int(kawgs.get('_host_index')) >= len(local_var_hosts):
                raise ApiValueError("Invalid host index. Must be 0 <= index < %s" % len(local_var_host))
            local_var_host = local_var_hosts[int(kwargs.get('_host_index'))]
        local_var_params = locals()

        all_params = ['offer_image_link_upload_request']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params and key != "_host_index":
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method upload_offer_image_using_post" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'offer_image_link_upload_request' is set
        if self.api_client.client_side_validation and ('offer_image_link_upload_request' not in local_var_params or  # noqa: E501
                                                        local_var_params['offer_image_link_upload_request'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `offer_image_link_upload_request` when calling `upload_offer_image_using_post`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'offer_image_link_upload_request' in local_var_params:
            body_params = local_var_params['offer_image_link_upload_request']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/vnd.allegro.public.v1+json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/vnd.allegro.public.v1+json', 'image/jpeg', 'image/png'])  # noqa: E501

        # Authentication setting
        auth_settings = ['bearer-token-for-user']  # noqa: E501

        return self.api_client.call_api(
            '/sale/images', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='OfferImageUploadResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            _host=local_var_host,
            collection_formats=collection_formats)



# coding: utf-8

"""
    Allegro REST API

    https://developer.allegro.pl/about  # noqa: E501

    The version of the OpenAPI document: 2020.03.10
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from allegro_api.configuration import Configuration


class UserRatingSummaryResponse(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'average_rates': 'AverageRates',
        'not_recommended': 'UserRatingSummaryResponseNotRecommended',
        'recommended': 'UserRatingSummaryResponseRecommended',
        'recommended_percentage': 'str'
    }

    attribute_map = {
        'average_rates': 'averageRates',
        'not_recommended': 'notRecommended',
        'recommended': 'recommended',
        'recommended_percentage': 'recommendedPercentage'
    }

    def __init__(self, average_rates=None, not_recommended=None, recommended=None, recommended_percentage=None, local_vars_configuration=None):  # noqa: E501
        """UserRatingSummaryResponse - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._average_rates = None
        self._not_recommended = None
        self._recommended = None
        self._recommended_percentage = None
        self.discriminator = None

        if average_rates is not None:
            self.average_rates = average_rates
        self.not_recommended = not_recommended
        self.recommended = recommended
        self.recommended_percentage = recommended_percentage

    @property
    def average_rates(self):
        """Gets the average_rates of this UserRatingSummaryResponse.  # noqa: E501


        :return: The average_rates of this UserRatingSummaryResponse.  # noqa: E501
        :rtype: AverageRates
        """
        return self._average_rates

    @average_rates.setter
    def average_rates(self, average_rates):
        """Sets the average_rates of this UserRatingSummaryResponse.


        :param average_rates: The average_rates of this UserRatingSummaryResponse.  # noqa: E501
        :type: AverageRates
        """

        self._average_rates = average_rates

    @property
    def not_recommended(self):
        """Gets the not_recommended of this UserRatingSummaryResponse.  # noqa: E501


        :return: The not_recommended of this UserRatingSummaryResponse.  # noqa: E501
        :rtype: UserRatingSummaryResponseNotRecommended
        """
        return self._not_recommended

    @not_recommended.setter
    def not_recommended(self, not_recommended):
        """Sets the not_recommended of this UserRatingSummaryResponse.


        :param not_recommended: The not_recommended of this UserRatingSummaryResponse.  # noqa: E501
        :type: UserRatingSummaryResponseNotRecommended
        """
        if self.local_vars_configuration.client_side_validation and not_recommended is None:  # noqa: E501
            raise ValueError("Invalid value for `not_recommended`, must not be `None`")  # noqa: E501

        self._not_recommended = not_recommended

    @property
    def recommended(self):
        """Gets the recommended of this UserRatingSummaryResponse.  # noqa: E501


        :return: The recommended of this UserRatingSummaryResponse.  # noqa: E501
        :rtype: UserRatingSummaryResponseRecommended
        """
        return self._recommended

    @recommended.setter
    def recommended(self, recommended):
        """Sets the recommended of this UserRatingSummaryResponse.


        :param recommended: The recommended of this UserRatingSummaryResponse.  # noqa: E501
        :type: UserRatingSummaryResponseRecommended
        """
        if self.local_vars_configuration.client_side_validation and recommended is None:  # noqa: E501
            raise ValueError("Invalid value for `recommended`, must not be `None`")  # noqa: E501

        self._recommended = recommended

    @property
    def recommended_percentage(self):
        """Gets the recommended_percentage of this UserRatingSummaryResponse.  # noqa: E501

        Percentage of unique buyers recommending the seller.  # noqa: E501

        :return: The recommended_percentage of this UserRatingSummaryResponse.  # noqa: E501
        :rtype: str
        """
        return self._recommended_percentage

    @recommended_percentage.setter
    def recommended_percentage(self, recommended_percentage):
        """Sets the recommended_percentage of this UserRatingSummaryResponse.

        Percentage of unique buyers recommending the seller.  # noqa: E501

        :param recommended_percentage: The recommended_percentage of this UserRatingSummaryResponse.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and recommended_percentage is None:  # noqa: E501
            raise ValueError("Invalid value for `recommended_percentage`, must not be `None`")  # noqa: E501

        self._recommended_percentage = recommended_percentage

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, UserRatingSummaryResponse):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, UserRatingSummaryResponse):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Allegro REST API

    https://developer.allegro.pl/about  # noqa: E501

    The version of the OpenAPI document: 2020.03.10
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from allegro_api.configuration import Configuration


class InlineResponse2001ShippingRatesConstraintsFirstItemRate(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'min': 'str',
        'max': 'str',
        'currency': 'str'
    }

    attribute_map = {
        'min': 'min',
        'max': 'max',
        'currency': 'currency'
    }

    def __init__(self, min=None, max=None, currency=None, local_vars_configuration=None):  # noqa: E501
        """InlineResponse2001ShippingRatesConstraintsFirstItemRate - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._min = None
        self._max = None
        self._currency = None
        self.discriminator = None

        if min is not None:
            self.min = min
        if max is not None:
            self.max = max
        if currency is not None:
            self.currency = currency

    @property
    def min(self):
        """Gets the min of this InlineResponse2001ShippingRatesConstraintsFirstItemRate.  # noqa: E501

        Lower limit for the rate.  # noqa: E501

        :return: The min of this InlineResponse2001ShippingRatesConstraintsFirstItemRate.  # noqa: E501
        :rtype: str
        """
        return self._min

    @min.setter
    def min(self, min):
        """Sets the min of this InlineResponse2001ShippingRatesConstraintsFirstItemRate.

        Lower limit for the rate.  # noqa: E501

        :param min: The min of this InlineResponse2001ShippingRatesConstraintsFirstItemRate.  # noqa: E501
        :type: str
        """
        if (self.local_vars_configuration.client_side_validation and
                min is not None and len(min) > 15):
            raise ValueError("Invalid value for `min`, length must be less than or equal to `15`")  # noqa: E501

        self._min = min

    @property
    def max(self):
        """Gets the max of this InlineResponse2001ShippingRatesConstraintsFirstItemRate.  # noqa: E501

        Upper limit for the rate.  # noqa: E501

        :return: The max of this InlineResponse2001ShippingRatesConstraintsFirstItemRate.  # noqa: E501
        :rtype: str
        """
        return self._max

    @max.setter
    def max(self, max):
        """Sets the max of this InlineResponse2001ShippingRatesConstraintsFirstItemRate.

        Upper limit for the rate.  # noqa: E501

        :param max: The max of this InlineResponse2001ShippingRatesConstraintsFirstItemRate.  # noqa: E501
        :type: str
        """
        if (self.local_vars_configuration.client_side_validation and
                max is not None and len(max) > 15):
            raise ValueError("Invalid value for `max`, length must be less than or equal to `15`")  # noqa: E501

        self._max = max

    @property
    def currency(self):
        """Gets the currency of this InlineResponse2001ShippingRatesConstraintsFirstItemRate.  # noqa: E501

        ISO 4217 currency code.  # noqa: E501

        :return: The currency of this InlineResponse2001ShippingRatesConstraintsFirstItemRate.  # noqa: E501
        :rtype: str
        """
        return self._currency

    @currency.setter
    def currency(self, currency):
        """Sets the currency of this InlineResponse2001ShippingRatesConstraintsFirstItemRate.

        ISO 4217 currency code.  # noqa: E501

        :param currency: The currency of this InlineResponse2001ShippingRatesConstraintsFirstItemRate.  # noqa: E501
        :type: str
        """

        self._currency = currency

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, InlineResponse2001ShippingRatesConstraintsFirstItemRate):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, InlineResponse2001ShippingRatesConstraintsFirstItemRate):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Allegro REST API

    https://developer.allegro.pl/about  # noqa: E501

    The version of the OpenAPI document: 2020.03.10
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from allegro_api.configuration import Configuration


class CategoryDto(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'id': 'str',
        'leaf': 'bool',
        'name': 'str',
        'options': 'CategoryOptionsDto',
        'parent': 'CategoryDtoParent'
    }

    attribute_map = {
        'id': 'id',
        'leaf': 'leaf',
        'name': 'name',
        'options': 'options',
        'parent': 'parent'
    }

    def __init__(self, id=None, leaf=None, name=None, options=None, parent=None, local_vars_configuration=None):  # noqa: E501
        """CategoryDto - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._id = None
        self._leaf = None
        self._name = None
        self._options = None
        self._parent = None
        self.discriminator = None

        if id is not None:
            self.id = id
        if leaf is not None:
            self.leaf = leaf
        if name is not None:
            self.name = name
        if options is not None:
            self.options = options
        if parent is not None:
            self.parent = parent

    @property
    def id(self):
        """Gets the id of this CategoryDto.  # noqa: E501

        The ID of the category. This can be either in UUID format or an integer format. You should be ready to accept any string value as the category ID.  # noqa: E501

        :return: The id of this CategoryDto.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this CategoryDto.

        The ID of the category. This can be either in UUID format or an integer format. You should be ready to accept any string value as the category ID.  # noqa: E501

        :param id: The id of this CategoryDto.  # noqa: E501
        :type: str
        """

        self._id = id

    @property
    def leaf(self):
        """Gets the leaf of this CategoryDto.  # noqa: E501

        Indicates whether the category is at the lowest level. Leaf categories do not have any children. Offers can be listed only in leaf categories.  # noqa: E501

        :return: The leaf of this CategoryDto.  # noqa: E501
        :rtype: bool
        """
        return self._leaf

    @leaf.setter
    def leaf(self, leaf):
        """Sets the leaf of this CategoryDto.

        Indicates whether the category is at the lowest level. Leaf categories do not have any children. Offers can be listed only in leaf categories.  # noqa: E501

        :param leaf: The leaf of this CategoryDto.  # noqa: E501
        :type: bool
        """

        self._leaf = leaf

    @property
    def name(self):
        """Gets the name of this CategoryDto.  # noqa: E501

        Name of the category in Polish.  # noqa: E501

        :return: The name of this CategoryDto.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this CategoryDto.

        Name of the category in Polish.  # noqa: E501

        :param name: The name of this CategoryDto.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def options(self):
        """Gets the options of this CategoryDto.  # noqa: E501


        :return: The options of this CategoryDto.  # noqa: E501
        :rtype: CategoryOptionsDto
        """
        return self._options

    @options.setter
    def options(self, options):
        """Sets the options of this CategoryDto.


        :param options: The options of this CategoryDto.  # noqa: E501
        :type: CategoryOptionsDto
        """

        self._options = options

    @property
    def parent(self):
        """Gets the parent of this CategoryDto.  # noqa: E501


        :return: The parent of this CategoryDto.  # noqa: E501
        :rtype: CategoryDtoParent
        """
        return self._parent

    @parent.setter
    def parent(self, parent):
        """Sets the parent of this CategoryDto.


        :param parent: The parent of this CategoryDto.  # noqa: E501
        :type: CategoryDtoParent
        """

        self._parent = parent

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, CategoryDto):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, CategoryDto):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Allegro REST API

    https://developer.allegro.pl/about  # noqa: E501

    The version of the OpenAPI document: 2020.03.10
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from allegro_api.configuration import Configuration


class Modification(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'additional_services_group': 'AdditionalServicesGroup',
        'delivery': 'ModificationDelivery',
        'payments': 'ModificationPayments',
        'promotion': 'ModificationPromotion',
        'size_table': 'ModificationSizeTable',
        'publication': 'ModificationPublication'
    }

    attribute_map = {
        'additional_services_group': 'additionalServicesGroup',
        'delivery': 'delivery',
        'payments': 'payments',
        'promotion': 'promotion',
        'size_table': 'sizeTable',
        'publication': 'publication'
    }

    def __init__(self, additional_services_group=None, delivery=None, payments=None, promotion=None, size_table=None, publication=None, local_vars_configuration=None):  # noqa: E501
        """Modification - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._additional_services_group = None
        self._delivery = None
        self._payments = None
        self._promotion = None
        self._size_table = None
        self._publication = None
        self.discriminator = None

        if additional_services_group is not None:
            self.additional_services_group = additional_services_group
        if delivery is not None:
            self.delivery = delivery
        if payments is not None:
            self.payments = payments
        if promotion is not None:
            self.promotion = promotion
        if size_table is not None:
            self.size_table = size_table
        if publication is not None:
            self.publication = publication

    @property
    def additional_services_group(self):
        """Gets the additional_services_group of this Modification.  # noqa: E501


        :return: The additional_services_group of this Modification.  # noqa: E501
        :rtype: AdditionalServicesGroup
        """
        return self._additional_services_group

    @additional_services_group.setter
    def additional_services_group(self, additional_services_group):
        """Sets the additional_services_group of this Modification.


        :param additional_services_group: The additional_services_group of this Modification.  # noqa: E501
        :type: AdditionalServicesGroup
        """

        self._additional_services_group = additional_services_group

    @property
    def delivery(self):
        """Gets the delivery of this Modification.  # noqa: E501


        :return: The delivery of this Modification.  # noqa: E501
        :rtype: ModificationDelivery
        """
        return self._delivery

    @delivery.setter
    def delivery(self, delivery):
        """Sets the delivery of this Modification.


        :param delivery: The delivery of this Modification.  # noqa: E501
        :type: ModificationDelivery
        """

        self._delivery = delivery

    @property
    def payments(self):
        """Gets the payments of this Modification.  # noqa: E501


        :return: The payments of this Modification.  # noqa: E501
        :rtype: ModificationPayments
        """
        return self._payments

    @payments.setter
    def payments(self, payments):
        """Sets the payments of this Modification.


        :param payments: The payments of this Modification.  # noqa: E501
        :type: ModificationPayments
        """

        self._payments = payments

    @property
    def promotion(self):
        """Gets the promotion of this Modification.  # noqa: E501


        :return: The promotion of this Modification.  # noqa: E501
        :rtype: ModificationPromotion
        """
        return self._promotion

    @promotion.setter
    def promotion(self, promotion):
        """Sets the promotion of this Modification.


        :param promotion: The promotion of this Modification.  # noqa: E501
        :type: ModificationPromotion
        """

        self._promotion = promotion

    @property
    def size_table(self):
        """Gets the size_table of this Modification.  # noqa: E501


        :return: The size_table of this Modification.  # noqa: E501
        :rtype: ModificationSizeTable
        """
        return self._size_table

    @size_table.setter
    def size_table(self, size_table):
        """Sets the size_table of this Modification.


        :param size_table: The size_table of this Modification.  # noqa: E501
        :type: ModificationSizeTable
        """

        self._size_table = size_table

    @property
    def publication(self):
        """Gets the publication of this Modification.  # noqa: E501


        :return: The publication of this Modification.  # noqa: E501
        :rtype: ModificationPublication
        """
        return self._publication

    @publication.setter
    def publication(self, publication):
        """Sets the publication of this Modification.


        :param publication: The publication of this Modification.  # noqa: E501
        :type: ModificationPublication
        """

        self._publication = publication

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Modification):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, Modification):
            return True

        return self.to_dict() != other.to_dict()



from __future__ import absolute_import

# flake8: noqa

# import apis into api package
from allegro_api.api.additional_services_api import AdditionalServicesApi
from allegro_api.api.after_sale_services_api import AfterSaleServicesApi
from allegro_api.api.auctions_and_bidding_api import AuctionsAndBiddingApi
from allegro_api.api.badge_campaigns_api import BadgeCampaignsApi
from allegro_api.api.batch_offer_modification_api import BatchOfferModificationApi
from allegro_api.api.billing_api import BillingApi
from allegro_api.api.blacklist_management_api import BlacklistManagementApi
from allegro_api.api.categories_and_parameters_api import CategoriesAndParametersApi
from allegro_api.api.classifieds_api import ClassifiedsApi
from allegro_api.api.compatibility_list_api import CompatibilityListApi
from allegro_api.api.contacts_api import ContactsApi
from allegro_api.api.delivery_api import DeliveryApi
from allegro_api.api.disputes_api import DisputesApi
from allegro_api.api.images_and_attachments_api import ImagesAndAttachmentsApi
from allegro_api.api.information_about_user_api import InformationAboutUserApi
from allegro_api.api.offer_management_api import OfferManagementApi
from allegro_api.api.offer_rating_api import OfferRatingApi
from allegro_api.api.offer_tags_api import OfferTagsApi
from allegro_api.api.offer_variants_api import OfferVariantsApi
from allegro_api.api.order_management_api import OrderManagementApi
from allegro_api.api.payments_api import PaymentsApi
from allegro_api.api.points_of_service_api import PointsOfServiceApi
from allegro_api.api.pricing_api import PricingApi
from allegro_api.api.products_api import ProductsApi
from allegro_api.api.promotion_campaigns_api import PromotionCampaignsApi
from allegro_api.api.public_offer_information_api import PublicOfferInformationApi
from allegro_api.api.public_user_information_api import PublicUserInformationApi
from allegro_api.api.sets_and_rebates_api import SetsAndRebatesApi
from allegro_api.api.size_tables_api import SizeTablesApi
from allegro_api.api.users_offer_information_api import UsersOfferInformationApi



# coding: utf-8

"""
    Allegro REST API

    https://developer.allegro.pl/about  # noqa: E501

    The version of the OpenAPI document: 2020.03.10
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from allegro_api.configuration import Configuration


class OfferQuoteDto(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'enabled': 'bool',
        'fee': 'Fee',
        'name': 'str',
        'next_date': 'datetime',
        'offer': 'OfferId',
        'type': 'str'
    }

    attribute_map = {
        'enabled': 'enabled',
        'fee': 'fee',
        'name': 'name',
        'next_date': 'nextDate',
        'offer': 'offer',
        'type': 'type'
    }

    def __init__(self, enabled=None, fee=None, name=None, next_date=None, offer=None, type=None, local_vars_configuration=None):  # noqa: E501
        """OfferQuoteDto - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._enabled = None
        self._fee = None
        self._name = None
        self._next_date = None
        self._offer = None
        self._type = None
        self.discriminator = None

        if enabled is not None:
            self.enabled = enabled
        if fee is not None:
            self.fee = fee
        if name is not None:
            self.name = name
        if next_date is not None:
            self.next_date = next_date
        if offer is not None:
            self.offer = offer
        if type is not None:
            self.type = type

    @property
    def enabled(self):
        """Gets the enabled of this OfferQuoteDto.  # noqa: E501


        :return: The enabled of this OfferQuoteDto.  # noqa: E501
        :rtype: bool
        """
        return self._enabled

    @enabled.setter
    def enabled(self, enabled):
        """Sets the enabled of this OfferQuoteDto.


        :param enabled: The enabled of this OfferQuoteDto.  # noqa: E501
        :type: bool
        """

        self._enabled = enabled

    @property
    def fee(self):
        """Gets the fee of this OfferQuoteDto.  # noqa: E501


        :return: The fee of this OfferQuoteDto.  # noqa: E501
        :rtype: Fee
        """
        return self._fee

    @fee.setter
    def fee(self, fee):
        """Sets the fee of this OfferQuoteDto.


        :param fee: The fee of this OfferQuoteDto.  # noqa: E501
        :type: Fee
        """

        self._fee = fee

    @property
    def name(self):
        """Gets the name of this OfferQuoteDto.  # noqa: E501


        :return: The name of this OfferQuoteDto.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this OfferQuoteDto.


        :param name: The name of this OfferQuoteDto.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def next_date(self):
        """Gets the next_date of this OfferQuoteDto.  # noqa: E501


        :return: The next_date of this OfferQuoteDto.  # noqa: E501
        :rtype: datetime
        """
        return self._next_date

    @next_date.setter
    def next_date(self, next_date):
        """Sets the next_date of this OfferQuoteDto.


        :param next_date: The next_date of this OfferQuoteDto.  # noqa: E501
        :type: datetime
        """

        self._next_date = next_date

    @property
    def offer(self):
        """Gets the offer of this OfferQuoteDto.  # noqa: E501


        :return: The offer of this OfferQuoteDto.  # noqa: E501
        :rtype: OfferId
        """
        return self._offer

    @offer.setter
    def offer(self, offer):
        """Sets the offer of this OfferQuoteDto.


        :param offer: The offer of this OfferQuoteDto.  # noqa: E501
        :type: OfferId
        """

        self._offer = offer

    @property
    def type(self):
        """Gets the type of this OfferQuoteDto.  # noqa: E501


        :return: The type of this OfferQuoteDto.  # noqa: E501
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        """Sets the type of this OfferQuoteDto.


        :param type: The type of this OfferQuoteDto.  # noqa: E501
        :type: str
        """

        self._type = type

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, OfferQuoteDto):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, OfferQuoteDto):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Allegro REST API

    https://developer.allegro.pl/about  # noqa: E501

    The version of the OpenAPI document: 2020.03.10
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from allegro_api.configuration import Configuration


class CompatibilityListSupportedCategoriesDtoSupportedCategories(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'category_id': 'str',
        'name': 'str',
        'items_type': 'str',
        'input_type': 'str',
        'validation_rules': 'CompatibilityListSupportedCategoriesDtoValidationRules'
    }

    attribute_map = {
        'category_id': 'categoryId',
        'name': 'name',
        'items_type': 'itemsType',
        'input_type': 'inputType',
        'validation_rules': 'validationRules'
    }

    def __init__(self, category_id=None, name=None, items_type=None, input_type=None, validation_rules=None, local_vars_configuration=None):  # noqa: E501
        """CompatibilityListSupportedCategoriesDtoSupportedCategories - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._category_id = None
        self._name = None
        self._items_type = None
        self._input_type = None
        self._validation_rules = None
        self.discriminator = None

        if category_id is not None:
            self.category_id = category_id
        if name is not None:
            self.name = name
        if items_type is not None:
            self.items_type = items_type
        if input_type is not None:
            self.input_type = input_type
        if validation_rules is not None:
            self.validation_rules = validation_rules

    @property
    def category_id(self):
        """Gets the category_id of this CompatibilityListSupportedCategoriesDtoSupportedCategories.  # noqa: E501

        Identifier of the category, where you can use the compatibility list in an offer listed in the category or in all subcategories, which belongs to returned category.  # noqa: E501

        :return: The category_id of this CompatibilityListSupportedCategoriesDtoSupportedCategories.  # noqa: E501
        :rtype: str
        """
        return self._category_id

    @category_id.setter
    def category_id(self, category_id):
        """Sets the category_id of this CompatibilityListSupportedCategoriesDtoSupportedCategories.

        Identifier of the category, where you can use the compatibility list in an offer listed in the category or in all subcategories, which belongs to returned category.  # noqa: E501

        :param category_id: The category_id of this CompatibilityListSupportedCategoriesDtoSupportedCategories.  # noqa: E501
        :type: str
        """

        self._category_id = category_id

    @property
    def name(self):
        """Gets the name of this CompatibilityListSupportedCategoriesDtoSupportedCategories.  # noqa: E501

        Name of supported category.  # noqa: E501

        :return: The name of this CompatibilityListSupportedCategoriesDtoSupportedCategories.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this CompatibilityListSupportedCategoriesDtoSupportedCategories.

        Name of supported category.  # noqa: E501

        :param name: The name of this CompatibilityListSupportedCategoriesDtoSupportedCategories.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def items_type(self):
        """Gets the items_type of this CompatibilityListSupportedCategoriesDtoSupportedCategories.  # noqa: E501

        Type of the compatible item.  # noqa: E501

        :return: The items_type of this CompatibilityListSupportedCategoriesDtoSupportedCategories.  # noqa: E501
        :rtype: str
        """
        return self._items_type

    @items_type.setter
    def items_type(self, items_type):
        """Sets the items_type of this CompatibilityListSupportedCategoriesDtoSupportedCategories.

        Type of the compatible item.  # noqa: E501

        :param items_type: The items_type of this CompatibilityListSupportedCategoriesDtoSupportedCategories.  # noqa: E501
        :type: str
        """

        self._items_type = items_type

    @property
    def input_type(self):
        """Gets the input_type of this CompatibilityListSupportedCategoriesDtoSupportedCategories.  # noqa: E501

        Type of the representation of compatible item. <ul> <li>`TEXT` - item on compatibility list has to be provided as plain text.</li> <li>`ID` - item on compatibility list has to be provided as identifier of compatible product. To obtain it please use <a href=\"/documentation/#tag/Compatibility-List/paths/~1sale~1compatible-products/get\">compatible-products</a> resource together with `itemsType` supported in particular category. </li> </ul>   # noqa: E501

        :return: The input_type of this CompatibilityListSupportedCategoriesDtoSupportedCategories.  # noqa: E501
        :rtype: str
        """
        return self._input_type

    @input_type.setter
    def input_type(self, input_type):
        """Sets the input_type of this CompatibilityListSupportedCategoriesDtoSupportedCategories.

        Type of the representation of compatible item. <ul> <li>`TEXT` - item on compatibility list has to be provided as plain text.</li> <li>`ID` - item on compatibility list has to be provided as identifier of compatible product. To obtain it please use <a href=\"/documentation/#tag/Compatibility-List/paths/~1sale~1compatible-products/get\">compatible-products</a> resource together with `itemsType` supported in particular category. </li> </ul>   # noqa: E501

        :param input_type: The input_type of this CompatibilityListSupportedCategoriesDtoSupportedCategories.  # noqa: E501
        :type: str
        """
        allowed_values = ["TEXT", "ID"]  # noqa: E501
        if self.local_vars_configuration.client_side_validation and input_type not in allowed_values:  # noqa: E501
            raise ValueError(
                "Invalid value for `input_type` ({0}), must be one of {1}"  # noqa: E501
                .format(input_type, allowed_values)
            )

        self._input_type = input_type

    @property
    def validation_rules(self):
        """Gets the validation_rules of this CompatibilityListSupportedCategoriesDtoSupportedCategories.  # noqa: E501


        :return: The validation_rules of this CompatibilityListSupportedCategoriesDtoSupportedCategories.  # noqa: E501
        :rtype: CompatibilityListSupportedCategoriesDtoValidationRules
        """
        return self._validation_rules

    @validation_rules.setter
    def validation_rules(self, validation_rules):
        """Sets the validation_rules of this CompatibilityListSupportedCategoriesDtoSupportedCategories.


        :param validation_rules: The validation_rules of this CompatibilityListSupportedCategoriesDtoSupportedCategories.  # noqa: E501
        :type: CompatibilityListSupportedCategoriesDtoValidationRules
        """

        self._validation_rules = validation_rules

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, CompatibilityListSupportedCategoriesDtoSupportedCategories):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, CompatibilityListSupportedCategoriesDtoSupportedCategories):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Allegro REST API

    https://developer.allegro.pl/about  # noqa: E501

    The version of the OpenAPI document: 2020.03.10
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import allegro_api
from allegro_api.models.classified_package_configs import ClassifiedPackageConfigs  # noqa: E501
from allegro_api.rest import ApiException

class TestClassifiedPackageConfigs(unittest.TestCase):
    """ClassifiedPackageConfigs unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test ClassifiedPackageConfigs
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = allegro_api.models.classified_package_configs.ClassifiedPackageConfigs()  # noqa: E501
        if include_optional :
            return ClassifiedPackageConfigs(
                packages = [
                    allegro_api.models.classified_package_config.ClassifiedPackageConfig(
                        extensions = [
                            allegro_api.models.classified_extension.ClassifiedExtension(
                                description = 'Autocentrum.pl', 
                                name = 'autocentrumExport', )
                            ], 
                        id = '6174be19-56f9-484b-b72c-43b0b00785e8', 
                        name = 'Power', 
                        promotions = [
                            allegro_api.models.classified_promotion.ClassifiedPromotion(
                                duration = 'PT240H', 
                                name = 'emphasized', )
                            ], 
                        publication = allegro_api.models.classified_publication.ClassifiedPublication(
                            duration = 'PT240H', ), 
                        type = 'BASE', )
                    ]
            )
        else :
            return ClassifiedPackageConfigs(
                packages = [
                    allegro_api.models.classified_package_config.ClassifiedPackageConfig(
                        extensions = [
                            allegro_api.models.classified_extension.ClassifiedExtension(
                                description = 'Autocentrum.pl', 
                                name = 'autocentrumExport', )
                            ], 
                        id = '6174be19-56f9-484b-b72c-43b0b00785e8', 
                        name = 'Power', 
                        promotions = [
                            allegro_api.models.classified_promotion.ClassifiedPromotion(
                                duration = 'PT240H', 
                                name = 'emphasized', )
                            ], 
                        publication = allegro_api.models.classified_publication.ClassifiedPublication(
                            duration = 'PT240H', ), 
                        type = 'BASE', )
                    ],
        )

    def testClassifiedPackageConfigs(self):
        """Test ClassifiedPackageConfigs"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Allegro REST API

    https://developer.allegro.pl/about  # noqa: E501

    The version of the OpenAPI document: 2020.03.10
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import allegro_api
from allegro_api.models.get_sale_products_response import GetSaleProductsResponse  # noqa: E501
from allegro_api.rest import ApiException

class TestGetSaleProductsResponse(unittest.TestCase):
    """GetSaleProductsResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test GetSaleProductsResponse
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = allegro_api.models.get_sale_products_response.GetSaleProductsResponse()  # noqa: E501
        if include_optional :
            return GetSaleProductsResponse(
                products = [
                    allegro_api.models.sale_product_response_dto.SaleProductResponseDto(
                        id = '0', 
                        name = '0', 
                        category = allegro_api.models.category.Category(
                            id = '0', ), 
                        eans = [
                            '0'
                            ], 
                        images = [
                            allegro_api.models.image_url.ImageUrl(
                                url = '0', )
                            ], 
                        parameters = [
                            allegro_api.models.product_parameter.ProductParameter(
                                id = '0', 
                                range_value = allegro_api.models.parameter_range_value.ParameterRangeValue(
                                    from = '0', 
                                    to = '0', ), 
                                values = [
                                    '0'
                                    ], 
                                values_ids = [
                                    '0'
                                    ], 
                                values_labels = [
                                    '0'
                                    ], 
                                unit = '0', 
                                options = [
                                    allegro_api.models.product_parameter_options.ProductParameter_options(
                                        identifies_product = True, )
                                    ], )
                            ], )
                    ], 
                categories = [
                    allegro_api.models.sale_product_response_categories_dto.SaleProductResponseCategoriesDto(
                        subcategories = [
                            allegro_api.models.products_category_subcategories.ProductsCategorySubcategories(
                                id = '0', 
                                name = '0', 
                                count = 56, )
                            ], 
                        path = [
                            allegro_api.models.products_category_path.ProductsCategoryPath(
                                id = '0', 
                                name = '0', )
                            ], )
                    ], 
                filters = [
                    allegro_api.models.listing_response_filters.ListingResponseFilters(
                        id = 'campaign', 
                        type = 'MULTI', 
                        name = 'kampania', 
                        values = [
                            allegro_api.models.listing_response_filters_values.ListingResponseFiltersValues(
                                name = 'raty zero', 
                                value = 'INSTALLMENTS_ZERO', 
                                id_suffix = '.to', 
                                count = 123, 
                                selected = True, )
                            ], 
                        min_value = 0, 
                        max_value = 1000, 
                        unit = 'zł', )
                    ], 
                next_page = allegro_api.models.get_sale_products_response_next_page.GetSaleProductsResponse_nextPage(
                    id = '0', )
            )
        else :
            return GetSaleProductsResponse(
                products = [
                    allegro_api.models.sale_product_response_dto.SaleProductResponseDto(
                        id = '0', 
                        name = '0', 
                        category = allegro_api.models.category.Category(
                            id = '0', ), 
                        eans = [
                            '0'
                            ], 
                        images = [
                            allegro_api.models.image_url.ImageUrl(
                                url = '0', )
                            ], 
                        parameters = [
                            allegro_api.models.product_parameter.ProductParameter(
                                id = '0', 
                                range_value = allegro_api.models.parameter_range_value.ParameterRangeValue(
                                    from = '0', 
                                    to = '0', ), 
                                values = [
                                    '0'
                                    ], 
                                values_ids = [
                                    '0'
                                    ], 
                                values_labels = [
                                    '0'
                                    ], 
                                unit = '0', 
                                options = [
                                    allegro_api.models.product_parameter_options.ProductParameter_options(
                                        identifies_product = True, )
                                    ], )
                            ], )
                    ],
        )

    def testGetSaleProductsResponse(self):
        """Test GetSaleProductsResponse"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Allegro REST API

    https://developer.allegro.pl/about  # noqa: E501

    The version of the OpenAPI document: 2020.03.10
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from allegro_api.api_client import ApiClient
from allegro_api.exceptions import (
    ApiTypeError,
    ApiValueError
)


class SetsAndRebatesApi(object):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def create_promotion_using_post1(self, seller_create_rebate_request_dto, **kwargs):  # noqa: E501
        """Create a new promotion  # noqa: E501

        This endpoint creates a new promotion. You can define the following types of promotions: 1. Bundle In order to create a new bundle, you have to define a  promotion with a single benefit of type **ORDER_FIXED_DISCOUNT** and a single criterion of type **CONTAINS_OFFERS**. In the benefit specification you have to declare the discount amount that you want to be deducted from the sum of bundled offers prices. In the offer criterion you need to pass a list of offers that are to be grouped as a bundle. For each offer you have to define a fixed quantity (that many pieces of your offer will be part of the bundle) and you also have to set a promotionEntryPoint flag (offers with this flag set to true will have a section that allows the users to purchase your bundle).  2. Multipack In order to create a new multipack, you have to define a promotion with a single benefit of type **UNIT_PERCENTAGE_DISCOUNT** and a single criterion of type **CONTAINS_OFFERS**. The benefit specification should contain a configuration section with a percentage which indicates the specific discount for the discounted offer. This percentage should be an integer value greater than 15 for quantity 2, greater than 30 for quantity 3, greater than 40 for quantity 4, greater than 50 for quantity 5 and lower than or equal to 100. The specification should also contain a trigger section with a field forEachQuantity that defines the amount of items in the multipack which is necessary to trigger the benefit. Additionally, the discountedNumber field must be set to 1 by default as you can only discount one unit in a multipack. Finally, the offer criterion specifies the offer for which the multipack promotion will take effect. 3. Cross-offer multipack A cross-offer multipack is created in the same fashion as a standard multipack. The only difference is that you need to pass more than 1 offer in the offer criterion section. This group of offers is then considered as a pool from which users can pick and choose forEachQuantity offers and the cheapest of them gets a discount. Read more about <a href=\"../../news/2017-10-18-news_promocyjne_zestawy_ofert/\" target=\"_blank\">bundles</a>, <a href=\"../../news/2018-02-01-rabaty_ilosciowe/\" target=\"_blank\">multipack</a> and <a href=\"../../news/2018-10-08-rabaty_ilosciowe/\" target=\"_blank\">cross-offer multipack</a>.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.create_promotion_using_post1(seller_create_rebate_request_dto, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param SellerCreateRebateRequestDto seller_create_rebate_request_dto: (required)
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: SellerRebateDto
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.create_promotion_using_post1_with_http_info(seller_create_rebate_request_dto, **kwargs)  # noqa: E501

    def create_promotion_using_post1_with_http_info(self, seller_create_rebate_request_dto, **kwargs):  # noqa: E501
        """Create a new promotion  # noqa: E501

        This endpoint creates a new promotion. You can define the following types of promotions: 1. Bundle In order to create a new bundle, you have to define a  promotion with a single benefit of type **ORDER_FIXED_DISCOUNT** and a single criterion of type **CONTAINS_OFFERS**. In the benefit specification you have to declare the discount amount that you want to be deducted from the sum of bundled offers prices. In the offer criterion you need to pass a list of offers that are to be grouped as a bundle. For each offer you have to define a fixed quantity (that many pieces of your offer will be part of the bundle) and you also have to set a promotionEntryPoint flag (offers with this flag set to true will have a section that allows the users to purchase your bundle).  2. Multipack In order to create a new multipack, you have to define a promotion with a single benefit of type **UNIT_PERCENTAGE_DISCOUNT** and a single criterion of type **CONTAINS_OFFERS**. The benefit specification should contain a configuration section with a percentage which indicates the specific discount for the discounted offer. This percentage should be an integer value greater than 15 for quantity 2, greater than 30 for quantity 3, greater than 40 for quantity 4, greater than 50 for quantity 5 and lower than or equal to 100. The specification should also contain a trigger section with a field forEachQuantity that defines the amount of items in the multipack which is necessary to trigger the benefit. Additionally, the discountedNumber field must be set to 1 by default as you can only discount one unit in a multipack. Finally, the offer criterion specifies the offer for which the multipack promotion will take effect. 3. Cross-offer multipack A cross-offer multipack is created in the same fashion as a standard multipack. The only difference is that you need to pass more than 1 offer in the offer criterion section. This group of offers is then considered as a pool from which users can pick and choose forEachQuantity offers and the cheapest of them gets a discount. Read more about <a href=\"../../news/2017-10-18-news_promocyjne_zestawy_ofert/\" target=\"_blank\">bundles</a>, <a href=\"../../news/2018-02-01-rabaty_ilosciowe/\" target=\"_blank\">multipack</a> and <a href=\"../../news/2018-10-08-rabaty_ilosciowe/\" target=\"_blank\">cross-offer multipack</a>.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.create_promotion_using_post1_with_http_info(seller_create_rebate_request_dto, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param SellerCreateRebateRequestDto seller_create_rebate_request_dto: (required)
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(SellerRebateDto, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = ['seller_create_rebate_request_dto']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method create_promotion_using_post1" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'seller_create_rebate_request_dto' is set
        if self.api_client.client_side_validation and ('seller_create_rebate_request_dto' not in local_var_params or  # noqa: E501
                                                        local_var_params['seller_create_rebate_request_dto'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `seller_create_rebate_request_dto` when calling `create_promotion_using_post1`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'seller_create_rebate_request_dto' in local_var_params:
            body_params = local_var_params['seller_create_rebate_request_dto']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/vnd.allegro.public.v1+json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/vnd.allegro.public.v1+json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['bearer-token-for-user']  # noqa: E501

        return self.api_client.call_api(
            '/sale/loyalty/promotions', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='SellerRebateDto',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def deactivate_promotion_using_delete(self, promotion_id, **kwargs):  # noqa: E501
        """Deactivate a promotion by id  # noqa: E501

        Use this resource to deactivate the requested promotion. You need to use its unique id. Read more about <a href=\"../../news/2017-10-18-news_promocyjne_zestawy_ofert/#4\" target=\"_blank\">bundles</a> and <a href=\"../../news/2018-02-01-rabaty_ilosciowe/#4\" target=\"_blank\">multipack</a>.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.deactivate_promotion_using_delete(promotion_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str promotion_id: Promotion identifier. (required)
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.deactivate_promotion_using_delete_with_http_info(promotion_id, **kwargs)  # noqa: E501

    def deactivate_promotion_using_delete_with_http_info(self, promotion_id, **kwargs):  # noqa: E501
        """Deactivate a promotion by id  # noqa: E501

        Use this resource to deactivate the requested promotion. You need to use its unique id. Read more about <a href=\"../../news/2017-10-18-news_promocyjne_zestawy_ofert/#4\" target=\"_blank\">bundles</a> and <a href=\"../../news/2018-02-01-rabaty_ilosciowe/#4\" target=\"_blank\">multipack</a>.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.deactivate_promotion_using_delete_with_http_info(promotion_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str promotion_id: Promotion identifier. (required)
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = ['promotion_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method deactivate_promotion_using_delete" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'promotion_id' is set
        if self.api_client.client_side_validation and ('promotion_id' not in local_var_params or  # noqa: E501
                                                        local_var_params['promotion_id'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `promotion_id` when calling `deactivate_promotion_using_delete`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'promotion_id' in local_var_params:
            path_params['promotionId'] = local_var_params['promotion_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['*/*'])  # noqa: E501

        # Authentication setting
        auth_settings = ['bearer-token-for-user']  # noqa: E501

        return self.api_client.call_api(
            '/sale/loyalty/promotions/{promotionId}', 'DELETE',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_promotion_using_get(self, promotion_id, **kwargs):  # noqa: E501
        """Get a promotion data by id  # noqa: E501

        Use this resource to returns the requested promotion. You need to use its unique id. Read more about <a href=\"../../news/2017-10-18-news_promocyjne_zestawy_ofert/#3\" target=\"_blank\">bundles</a> and <a href=\"../../news/2018-02-01-rabaty_ilosciowe/#3\" target=\"_blank\">multipack</a>.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_promotion_using_get(promotion_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str promotion_id: Promotion identifier. (required)
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: SellerRebateDto
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.get_promotion_using_get_with_http_info(promotion_id, **kwargs)  # noqa: E501

    def get_promotion_using_get_with_http_info(self, promotion_id, **kwargs):  # noqa: E501
        """Get a promotion data by id  # noqa: E501

        Use this resource to returns the requested promotion. You need to use its unique id. Read more about <a href=\"../../news/2017-10-18-news_promocyjne_zestawy_ofert/#3\" target=\"_blank\">bundles</a> and <a href=\"../../news/2018-02-01-rabaty_ilosciowe/#3\" target=\"_blank\">multipack</a>.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_promotion_using_get_with_http_info(promotion_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str promotion_id: Promotion identifier. (required)
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(SellerRebateDto, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = ['promotion_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_promotion_using_get" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'promotion_id' is set
        if self.api_client.client_side_validation and ('promotion_id' not in local_var_params or  # noqa: E501
                                                        local_var_params['promotion_id'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `promotion_id` when calling `get_promotion_using_get`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'promotion_id' in local_var_params:
            path_params['promotionId'] = local_var_params['promotion_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/vnd.allegro.public.v1+json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['bearer-token-for-user']  # noqa: E501

        return self.api_client.call_api(
            '/sale/loyalty/promotions/{promotionId}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='SellerRebateDto',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def list_seller_promotions_using_get1(self, user_id, **kwargs):  # noqa: E501
        """Get the user's list of promotions  # noqa: E501

        <p>Get a list of promotions defined by the authorized user.</p> <p>Restrictions:</p> <p>Sum of limit and offset must be equal to or lower than 50000. Limit must be equal to or lower than 5000.</p> <p>Example:</p> <p>offset = 49950 and limit = 50 will return promotions</p> <p>offset = 49950 and limit = 51 will return 422 http error</p> <p>offset = 0 and limit = 5000 will return promotions</p> <p>offset = 0 and limit = 5001 will return 422 http error</p> <p>Read more about <a href=\"../../news/2017-10-18-news_promocyjne_zestawy_ofert/#2\" target=\"_blank\">Bundles</a> and <a href=\"../../news/2018-02-01-rabaty_ilosciowe/#2\" target=\"_blank\">Multipack</a>.</p>  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.list_seller_promotions_using_get1(user_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str user_id: The id of the user who is the owner of the promotions. (required)
        :param int limit: Limit of promotions per page.
        :param int offset: Distance between the beginning of the document and the point from which promotions are returned.
        :param str offer_id: Filter by offer id.
        :param str promotion_type: Filter by promotion type.
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: SellerRebatesDto
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.list_seller_promotions_using_get1_with_http_info(user_id, **kwargs)  # noqa: E501

    def list_seller_promotions_using_get1_with_http_info(self, user_id, **kwargs):  # noqa: E501
        """Get the user's list of promotions  # noqa: E501

        <p>Get a list of promotions defined by the authorized user.</p> <p>Restrictions:</p> <p>Sum of limit and offset must be equal to or lower than 50000. Limit must be equal to or lower than 5000.</p> <p>Example:</p> <p>offset = 49950 and limit = 50 will return promotions</p> <p>offset = 49950 and limit = 51 will return 422 http error</p> <p>offset = 0 and limit = 5000 will return promotions</p> <p>offset = 0 and limit = 5001 will return 422 http error</p> <p>Read more about <a href=\"../../news/2017-10-18-news_promocyjne_zestawy_ofert/#2\" target=\"_blank\">Bundles</a> and <a href=\"../../news/2018-02-01-rabaty_ilosciowe/#2\" target=\"_blank\">Multipack</a>.</p>  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.list_seller_promotions_using_get1_with_http_info(user_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str user_id: The id of the user who is the owner of the promotions. (required)
        :param int limit: Limit of promotions per page.
        :param int offset: Distance between the beginning of the document and the point from which promotions are returned.
        :param str offer_id: Filter by offer id.
        :param str promotion_type: Filter by promotion type.
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(SellerRebatesDto, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = ['user_id', 'limit', 'offset', 'offer_id', 'promotion_type']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method list_seller_promotions_using_get1" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'user_id' is set
        if self.api_client.client_side_validation and ('user_id' not in local_var_params or  # noqa: E501
                                                        local_var_params['user_id'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `user_id` when calling `list_seller_promotions_using_get1`")  # noqa: E501

        if self.api_client.client_side_validation and 'limit' in local_var_params and local_var_params['limit'] > 5000:  # noqa: E501
            raise ApiValueError("Invalid value for parameter `limit` when calling `list_seller_promotions_using_get1`, must be a value less than or equal to `5000`")  # noqa: E501
        if self.api_client.client_side_validation and 'limit' in local_var_params and local_var_params['limit'] < 1:  # noqa: E501
            raise ApiValueError("Invalid value for parameter `limit` when calling `list_seller_promotions_using_get1`, must be a value greater than or equal to `1`")  # noqa: E501
        if self.api_client.client_side_validation and 'offset' in local_var_params and local_var_params['offset'] > 49999:  # noqa: E501
            raise ApiValueError("Invalid value for parameter `offset` when calling `list_seller_promotions_using_get1`, must be a value less than or equal to `49999`")  # noqa: E501
        if self.api_client.client_side_validation and 'offset' in local_var_params and local_var_params['offset'] < 0:  # noqa: E501
            raise ApiValueError("Invalid value for parameter `offset` when calling `list_seller_promotions_using_get1`, must be a value greater than or equal to `0`")  # noqa: E501
        collection_formats = {}

        path_params = {}

        query_params = []
        if 'user_id' in local_var_params and local_var_params['user_id'] is not None:  # noqa: E501
            query_params.append(('user.id', local_var_params['user_id']))  # noqa: E501
        if 'limit' in local_var_params and local_var_params['limit'] is not None:  # noqa: E501
            query_params.append(('limit', local_var_params['limit']))  # noqa: E501
        if 'offset' in local_var_params and local_var_params['offset'] is not None:  # noqa: E501
            query_params.append(('offset', local_var_params['offset']))  # noqa: E501
        if 'offer_id' in local_var_params and local_var_params['offer_id'] is not None:  # noqa: E501
            query_params.append(('offer.id', local_var_params['offer_id']))  # noqa: E501
        if 'promotion_type' in local_var_params and local_var_params['promotion_type'] is not None:  # noqa: E501
            query_params.append(('promotionType', local_var_params['promotion_type']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/vnd.allegro.public.v1+json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['bearer-token-for-user']  # noqa: E501

        return self.api_client.call_api(
            '/sale/loyalty/promotions', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='SellerRebatesDto',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)
